@@ -596,7 +596,7 @@ def start(format: bool = False):
 
 if "__main__" == __name__:
     HOME_PATH = Path(".")
-    DESTINATION_PATH = Path("../../pyrogram/raw")
+    DESTINATION_PATH = Path("../../pyroxd/raw")
     NOTICE_PATH = Path("../../NOTICE")
 
     start(format=False)
